/*
* DOM and Window loading essentials
*/

declare const createjs: any;

const Sounds: Array<string> = new Array; // Available sounds...
createjs.Sound.on('fileload', (event: { id: string }) => { // This is fired for each sound that is registered...
    Sounds.push(event.id);
});
// No need to wait for either DOM or Window loaded:
createjs.Sound.registerSound("./sounds/Baby_crying.mp3", "Baby_crying_sound_ID");
// createjs.Sound.registerSound("./sounds/Baby_laughing.mp3", "Baby_laughing_sound_ID");

let Theo: HTMLImageElement | null = null;

window.document.onreadystatechange = function () { // Called *TWO TIMES*: when 'interactive' and later on... when 'complete'
    if (window.document.readyState === 'interactive') {
        window.console.log("DOM just loaded...");
        Theo = window.document.getElementById("Theo") as HTMLImageElement;
        Theo.addEventListener('mouseover', function () {
            if (Sounds.indexOf("Baby_crying_sound_ID") !== -1) {
                const sound = createjs.Sound.play("Baby_crying_sound_ID");
                sound.on('complete', () => window.console.log("Baby_crying_sound_ID" + " just completed..."));
            }
        });
    } else {
        if (window.document.readyState === 'complete') {
            window.console.log("Window just loaded...");
            if (Theo === null) { // We missed 'interactive'...
                Theo = window.document.getElementById("Theo") as HTMLImageElement;
                Theo.addEventListener('mouseover', function () {
                    if (Sounds.indexOf("Baby_crying_sound_ID") !== -1) {
                        const sound = createjs.Sound.play("Baby_crying_sound_ID");
                        sound.on('complete', () => window.console.log("Baby_crying_sound_ID" + " just completed..."));
                    }
                });
            }
            let image = new Image();
            image.onload = function () {
                window.console.log("Image ready for processing? " + image.width, 'x', image.height);
            };
            image.src = Theo.src; // Image load starts...
        }
    }
};

// window.addEventListener('DOMContentLoaded', (event: Event) => {
//     window.console.assert(window.document.readyState === 'interactive');
//     window.console.log("DOM just loaded...");
//     // Main_first_part(); // Call 'Main_first_part' program: access DOM resources...
// });
//
// window.addEventListener('load', (event: Event) => {
//     window.console.assert(window.document.readyState === 'complete');
//     window.console.log("Window just loaded...");
//     // Main_second_part(); // Call 'Main_second_part' program: access *ALL* resources...
// });
// // Xor:
// window.onload = (event: Event) => {
//     window.console.assert(window.document.readyState === 'complete');
//     window.console.log("Window just loaded...");
//     // Main_second_part(); // Call 'Main_second_part' program: access *ALL* resources...
// };
//
// window.addEventListener('beforeunload', (event: BeforeUnloadEvent) => {
//     window.console.log("About to leave: -all resources- are still there, but...");
// });
//
// let DOM_ready = null;
// Object.defineProperty(window, "DOM_ready", {
//     value: new Promise(launched_function_when_DOM_ready => {
//         DOM_ready = launched_function_when_DOM_ready;
//     }), enumerable: false, configurable: false, writable: false
// });
// window.document.onreadystatechange = DOM_ready;
//
// // In other places, one may check whether the DOM is ready:
// (window as any).DOM_ready.then(() => {
//     window.document.body.offsetWidth; // Access to 'body' content...
//     window.document.body.offsetHeight; // Access to 'body' content...
//     // Etc.
// });
//
// let Window_loaded: ((event: Event) => void) | undefined = undefined;
// Object.defineProperty(window, "Window_loaded", {
//     value: new Promise(launched_function_when_Window_loaded => {
//         Window_loaded = launched_function_when_Window_loaded;
//     }), enumerable: false, configurable: false, writable: false
// });
// window.addEventListener('load', Window_loaded!);
//
// // In other places, one may check whether both the DOM is ready and the browser window (images, sounds, videos...) is loaded:
// Promise.all([(window as any).DOM_ready, (window as any).Window_loaded]).then(value => {
//     /* 'value' is an array of results provided by 'window.DOM_ready' and 'window.Window_loaded' */
//     window.alert("Everything is now ready for the Web!");
// });
